awesome_extensions library
Classes
- AvatarImage
- ImageSize
- ImageSize is used to change the size of the widget.
- MyPlatform
- Nil
- A widget which is not in the layout and does nothing. It is useful when you have to return a widget and can't return null.
- Shimmer
- A widget renders shimmer effect over child widget tree.
- ShimmerState
Enums
- AvatarImageShape
- AvatarImageShape is used to shape the AvatarImage widget.
- ShimmerDirection
- An enum defines all supported directions of shimmer effect
Extensions
- AlignExtensions on Widget
-
AsyncSnapshotExt
on AsyncSnapshot<
T> - An extension on AsyncSnapshot providing a when method.
- CenterExtension on Widget
- ColorExtension on Color
- Extension on the Color class to provide additional functionality.
- ColorSchemeExt on BuildContext
- ContainerExtensions on Container
- DateOnlyCompare on DateTime
- DialogExt on BuildContext
- ExpandedExtension on Widget
- FlexibleExtension on Widget
- GestureDetectorExtensions on Widget
- ListExtension on List
-
MapExtension
on Map<
K, V> - Core utility extensions for Map operations
- MediaQueryExt on BuildContext
-
NestedMapExtension
on Map<
String, dynamic> - Extensions for nested map operations using dot notation
- NumExtension on num
- OpacityExtension on Widget
- PaddingX on Widget
- PositionedExtensions on Widget
- ShimmerEffect on Widget
- SizeBoxExtension on double
- SizeBoxNumExtension on num
- SnackbarExt on BuildContext
- StringExtension on String
- StyledText on T
- ThemeExt on BuildContext
- TxtStyle on TextStyle
- WidgetCommonExtension on Widget
- WidgetsExtension on Widget
- WidgetSliver on Widget
Functions
-
setHashUrlStrategy(
) → void -
Sets the URL strategy of your web app to using a leading has (
#) instead of paths. -
setPathUrlStrategy(
) → void -
Sets the URL strategy of your web app to using paths instead of a leading
hash (
#).